DraggableCard class

Inheritance

Constructors

DraggableCard({Widget? card, Widget? likeTag, Widget? nopeTag, Widget? superLikeTag, bool isDraggable = true, dynamic onSlideUpdate(double distance)?, dynamic onSlideOutComplete(SlideDirection? direction)?, SlideDirection? slideTo, dynamic onSlideRegionUpdate(SlideRegion? slideRegion)?, bool upSwipeAllowed = false, bool leftSwipeAllowed = true, bool rightSwipeAllowed = true, bool isBackCard = false, EdgeInsets padding = EdgeInsets.zero})

Properties

card → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
isBackCard → bool
final
isDraggable → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftSwipeAllowed → bool
final
likeTag → Widget?
final
nopeTag → Widget?
final
onSlideOutComplete → dynamic Function(SlideDirection? direction)?
final
onSlideRegionUpdate → dynamic Function(SlideRegion? slideRegion)?
final
onSlideUpdate → dynamic Function(double distance)?
final
padding → EdgeInsets
final
rightSwipeAllowed → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideTo → SlideDirection?
final
superLikeTag → Widget?
final
upSwipeAllowed → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _DraggableCardState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited